@@ -44,7 +44,7 @@ CDraftFrame::CDraftFrame()
 	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
 	this->m_hide = FALSE;
 	this->m_flag = FALSE;
-	this->m_account = mf->m_pAcntV->GetCurrentAccountName();
+//	this->m_account = mf->m_pAcntV->GetCurrentAccountName();
 	this->m_hide_attach = FALSE;
 	this->m_button_gpg = app->m_gpg_enable;
 	this->m_button_gpgenc = app->m_gpg_enable;
@@ -86,8 +86,11 @@ BEGIN_MESSAGE_MAP(CDraftFrame, CFrameWnd)
 	ON_NOTIFY(TBN_DROPDOWN, AFX_IDW_TOOLBAR, OnToolbarDropDown)
 	ON_COMMAND(ID_CHANGE_BK_COLOR_DRAFT, OnChangeBkColorDraft)
 	ON_COMMAND(ID_CHANGE_TXT_COLOR_DRAFT, OnChangeTxtColorDraft)
-	ON_UPDATE_COMMAND_UI(ID_DRAFT_GPG, OnUpdateGpg)
 	ON_COMMAND(ID_GPG_DRAFT_KEY_MANAGEMENT, OnGpgKeyManagement)
+	ON_WM_COPYDATA()
+	ON_WM_CHAR()
+	ON_UPDATE_COMMAND_UI(ID_DRAFT_GPG, OnUpdateGpg)
+	ON_WM_KEYDOWN()
 	//}}AFX_MSG_MAP
 	ON_COMMAND(WM_END, OnEnd)
 	ON_COMMAND(WM_PROGCREATE, OnProgCreate)
@@ -128,12 +131,6 @@ int CDraftFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
 
 	if(!this->CreateToolbar())
 		return -1;
-	// dropdown menu
-	// gpg
-	this->m_wndToolBar.GetToolBarCtrl().SetExtendedStyle(TBSTYLE_EX_DRAWDDARROWS);
-	DWORD style = this->m_wndToolBar.GetButtonStyle(m_wndToolBar.CommandToIndex(ID_DRAFT_GPG));
-	style |= TBSTYLE_DROPDOWN;
-	this->m_wndToolBar.SetButtonStyle(m_wndToolBar.CommandToIndex(ID_DRAFT_GPG), style);
 
 	if (!this->m_wndStatusBar.Create(this) ||
 		!this->m_wndStatusBar.SetIndicators(indicators, sizeof(indicators)/sizeof(UINT)))
@@ -226,6 +223,7 @@ BOOL CDraftFrame::OnCreateClient(LPCREATESTRUCT lpcs, CCreateContext* pContext)
 	this->m_wndSplit1.CreateView(0, 0, RUNTIME_CLASS(CAddressView), CSize(0,HT_HEAD), pContext);
 	this->m_wndSplit1.CreateView(1, 0, RUNTIME_CLASS(CMailEditView), CSize(0, 0), pContext);
 	this->m_wndSplit1.NoBorder();
+	this->m_wndSplit1.SetStaticBorder(TRUE);
 	this->m_wndSplit.CreateView(1, 0, RUNTIME_CLASS(CAttachedFileView), CSize(0, 0), pContext);
 
 	this->m_pAddrsV = (CAddressView*)m_wndSplit1.GetPane(0, 0);
@@ -233,6 +231,10 @@ BOOL CDraftFrame::OnCreateClient(LPCREATESTRUCT lpcs, CCreateContext* pContext)
 	this->m_pListV2 = (CAttachedFileView*)m_wndSplit.GetPane(1, 0);
 	this->m_me.CopyFrom(&app->m_me);
 
+	// CAddressView̃TCY
+	CSize size = this->m_pAddrsV->GetTotalSize();
+	this->m_wndSplit1.SetRowInfo(0, size.cy, size.cy);
+
 	// initialyzation
 	this->m_pAddrsV->OnInitialUpdate();
 	this->m_pEditV->OnInitialUpdate();
@@ -248,10 +250,10 @@ BOOL CDraftFrame::OnCreateClient(LPCREATESTRUCT lpcs, CCreateContext* pContext)
 
 	// setting account name in window title.
 	// below is stupid, but cannot find out better way.
-	CString title;
-	CString account = mf->m_pAcntV->GetCurrentAccountName();
-	title.Format("%s - %s", account, "draft");
-	this->SetWindowText(title);
+//	CString title;
+//	CString account = mf->m_pAcntV->GetCurrentAccountName();
+//	title.Format("%s - %s", m_account, "draft");
+//	this->SetWindowText(title);
 
 	return TRUE;
 }
@@ -346,6 +348,9 @@ void CDraftFrame::CloseIME(CView* view)
 
 void CDraftFrame::RecoverIME(CView* view)
 {
+	if(view == NULL){
+		return;
+	}
 	HIMC hImc = ImmGetContext(view->GetSafeHwnd());
 	ImmSetOpenStatus(hImc, this->m_ime_status);
 	ImmReleaseContext(view->GetSafeHwnd(), hImc);
@@ -472,15 +477,15 @@ void CDraftFrame::OnGpgEnc()
 
 	// selection of key.
 	CPochyApp* app = (CPochyApp*)AfxGetApp();
-	CGpgKeyListDlg lkd;
+	CGpgKeyListDlg lkd(this);
 	CString recipient;
 	recipient.Empty();
-	if(lkd.DoModal()==IDOK && app->m_key_id_list.GetSize()){
+	if(lkd.DoModal()==IDOK && this->m_key_id_list.GetSize()){
 		// preparation of executing process.
 		CStringArray list;
 		CString recipient;
-		for(int i=0;i<app->m_key_id_list.GetSize();i++){
-			recipient = app->m_key_id_list[i];
+		for(int i=0; i<this->m_key_id_list.GetSize(); i++){
+			recipient = this->m_key_id_list[i];
 			list.Add(recipient);
 		}
 		CString body;
@@ -527,9 +532,9 @@ void CDraftFrame::OnGpgExport()
 	// selection of key.
 	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	CGpgKeyListDlg lkd;
-	if(lkd.DoModal()==IDOK && app->m_key_id_list.GetSize()){
+	if(lkd.DoModal()==IDOK && this->m_key_id_list.GetSize()){
 		// below may work under conditon that GpgKeyListDlg cannot accept multiple selection.
-		CString id = app->m_key_id_list[0];
+		CString id = this->m_key_id_list[0];
 		CString out = gpg.ExportKey(id);
 		this->m_me.AddPgpKey(out);
 		this->m_pListV2->AddPgpKey();
@@ -598,7 +603,7 @@ BOOL CDraftFrame::CreateToolbar()
 {
 	DWORD dwTBStyle, dwStyle;
 
-	dwTBStyle = TBSTYLE_FLAT;
+	dwTBStyle = TBSTYLE_FLAT; // ̕ӂ̃X^C͓K
 	dwStyle = WS_CHILD | WS_VISIBLE | CBRS_TOP | CBRS_TOOLTIPS | CBRS_FLYBY | CBRS_SIZE_DYNAMIC;
 	if(!m_wndToolBar.CreateEx(this, dwTBStyle, dwStyle)){
 		TRACE0("Failed to create toolbar\n");
@@ -623,7 +628,13 @@ BOOL CDraftFrame::CreateToolbar()
 	m_wndToolBar.SetButtonInfo(4, ID_SAVE_TO_DRAFT, TBSTYLE_BUTTON, 4);
 	m_wndToolBar.SetButtonInfo(5, ID_DRAFT_EXT_EDITOR, TBSTYLE_BUTTON, 5);
 
+	// dropdown menu
     m_wndToolBar.GetToolBarCtrl().SetExtendedStyle(TBSTYLE_EX_DRAWDDARROWS);
+	// gpg
+	this->m_wndToolBar.GetToolBarCtrl().SetExtendedStyle(TBSTYLE_EX_DRAWDDARROWS);
+	DWORD style = this->m_wndToolBar.GetButtonStyle(m_wndToolBar.CommandToIndex(ID_DRAFT_GPG));
+	style |= TBSTYLE_DROPDOWN;
+	this->m_wndToolBar.SetButtonStyle(m_wndToolBar.CommandToIndex(ID_DRAFT_GPG), style);
 
 	return TRUE;
 }
@@ -730,6 +741,17 @@ void CDraftFrame::OnToolbarDropDown(NMTOOLBAR* pnmtb, LRESULT *plr)
 
 BOOL CDraftFrame::PreCreateWindow(CREATESTRUCT& cs) 
 {
+    // EBhENXo^
+    // EBhE₷Ȃ邩HOOG
+	if (cs.lpszName){
+		WNDCLASS wc;
+		::GetClassInfo(AfxGetInstanceHandle(), cs.lpszClass, &wc);
+		// _T()ň͂ĂȂdebug[hŎsiHj
+		wc.lpszClassName = _T("_PochyClass"); // DȖOݒ
+		AfxRegisterClass(&wc);
+		cs.lpszClass = wc.lpszClassName;
+	}
+
 	BOOL r = CFrameWnd::PreCreateWindow(cs);
 	cs.style ^= FWS_ADDTOTITLE;
 	return r;
@@ -789,3 +811,24 @@ void CDraftFrame::OnGpgKeyManagement()
 	CGpgDlg gd;
 	gd.DoModal();
 }
+
+BOOL CDraftFrame::OnCopyData(CWnd* pWnd, COPYDATASTRUCT* pCopyDataStruct) 
+{
+	if(pCopyDataStruct->dwData == WM_TITLE){
+		CString title = (char *)pCopyDataStruct->lpData;
+		this->SetWindowText(title);
+	}
+	return CFrameWnd::OnCopyData(pWnd, pCopyDataStruct);
+}
+
+void CDraftFrame::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags) 
+{
+	this->Char(nChar, NULL);
+	CFrameWnd::OnChar(nChar, nRepCnt, nFlags);
+}
+
+void CDraftFrame::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags) 
+{
+	this->KeyDown(nChar, NULL);
+	CFrameWnd::OnKeyDown(nChar, nRepCnt, nFlags);
+}
