@@ -94,27 +94,33 @@ void CFolderView::OnInitialUpdate()
 	CTreeCtrl& tc = GetTreeCtrl();
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 
-	// icon̐ݒ
-	// CImageListCreatebitmap\[XIDw肷ƁA16FɂȂĂ܂߁A
-	// CImageListFbitw肵CreateĂbitmap\[XAddB
-	BOOL is_ok = m_image.Create(17, 16, ILC_COLOR8|ILC_MASK, 0, 7);
-	if(is_ok){
+	// setting image for drag
+	if(this->m_drag_image.Create(15, 15, ILC_COLOR8|ILC_MASK, 0, 2)){
 		CBitmap bmp;
-		is_ok = bmp.LoadBitmap(IDB_TREEVIEW);
-		if(is_ok){
-			m_image.Add(&bmp, RGB(255,255,255));
+		if(bmp.LoadBitmap(IDB_DRAG)){
+			this->m_drag_image.Add(&bmp, RGB(255,255,255));
 		}
+		bmp.DeleteObject();
+	}
+
+	// icon̐ݒ
+	if(this->m_image.Create(17, 16, ILC_COLOR8|ILC_MASK, 0, 7)){
+		CBitmap bmp;
+		if(bmp.LoadBitmap(IDB_TREEVIEW)){
+			this->m_image.Add(&bmp, RGB(255,255,255));
+		}
+		bmp.DeleteObject();
 	}
 	tc.SetImageList(&m_image, TVSIL_NORMAL);
 
 	// c[Rg[ׂ̂ẴACe폜
 	tc.DeleteAllItems();	// 炢ȂH
 
-	// ݂̃r[̃X^C擾܂
+	// ݂̃r[̃X^C擾
 	hWnd = tc.GetSafeHwnd();
 	dwStyle = GetWindowLong(hWnd, GWL_STYLE);
 
-	// r[̃X^CύX܂
+	// r[̃X^CύX
 	SetWindowLong(hWnd, GWL_STYLE,
 		dwStyle|TVS_HASLINES/*|TVS_LINESATROOT*/|TVS_HASBUTTONS|TVS_EDITLABELS|TVS_SHOWSELALWAYS);
 
@@ -192,8 +198,8 @@ void CFolderView::OnSelchanged(NMHDR* pNMHDR, LRESULT* pResult)
 	// multipartviewBĂȂΉB
 	mf->HideMultiPartView(TRUE);
 
-	CString empty = "";
-	tv->Update(empty); // textviewɋ\
+	// display empty on textview
+	tv->Clear();
 
 	// ̃hLgJg[{bNXɂ
 //	GetDocument()->SetTitle(mf->m_pAcntV->GetCurrentAccountName());
@@ -299,7 +305,7 @@ void CFolderView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags)
 	CTreeCtrl& treeCtrl = GetTreeCtrl();
 	HTREEITEM ti;
 
-	if(mf->Char(nChar, this))
+	if(mf->Char(nChar))
 		return;
 
 	switch(nChar){
@@ -582,8 +588,6 @@ void CFolderView::OnLButtonUp(UINT nFlags, CPoint point)
 		CImageList::EndDrag();
 		ReleaseCapture();
 
-		delete m_pDragImage;
-
 		// Remove drop target highlighting
 		GetTreeCtrl().SelectDropTarget(NULL);
 
@@ -599,7 +603,7 @@ void CFolderView::OnLButtonUp(UINT nFlags, CPoint point)
 				if(WhatKind(m_hitemDrag) != FV_OTHER)
 					return;
 			}
-			// If Drag item is an ancestor of Drop item then return
+
 			HTREEITEM htiParent = m_hitemDrop;
 			while( (htiParent = GetTreeCtrl().GetParentItem( htiParent )) != NULL ){
 				if( htiParent == m_hitemDrag ) return;
@@ -618,29 +622,23 @@ void CFolderView::OnLButtonUp(UINT nFlags, CPoint point)
 			GetTreeCtrl().DeleteItem(m_hitemDrag);
 			GetTreeCtrl().SelectItem(htiNew);
 		}else{
-			CStringArray cstra;
-			cstra.RemoveAll();
 			if(sv->m_path == app->m_app_path + GetItemPath(m_hitemDrop))
 				return;
-			g_file2cstra(sv->m_path+"\\"+sv->m_array_list.GetAt(sv->m_stack_num - m_ListItemDrag - 1).m_str5, cstra);
-			// inbox outbox draft trash̏ꍇ̏
+
+			CWaitCursor wait_cursor; // turn cursor into sandglass
+			CUIntArray ia;
+
 			switch(WhatKind(m_hitemDrop)){
 			case FV_INBOX:
 			case FV_OTHER:
-				sv->SaveMail(app->m_app_path + GetItemPath(m_hitemDrop), cstra, SMRY_STATUS_NONE, SMRY_COLUMN_FROM);
-				sv->DeleteMail(m_ListItemDrag);
-				sv->WriteList();
+			case FV_TRASH:
+				sv->GetSelectedMail(ia);
+				sv->MoveMail(ia, app->m_app_path+GetItemPath(m_hitemDrop), SMRY_COLUMN_FROM);
 				break;
 			case FV_OUTBOX:
 			case FV_DRAFT:
-				sv->SaveMail(app->m_app_path + GetItemPath(m_hitemDrop), cstra, SMRY_STATUS_NONE, SMRY_COLUMN_TO);
-				sv->DeleteMail(m_ListItemDrag);
-				sv->WriteList();
-				break;
-			case FV_TRASH:
-				sv->SaveMail(app->m_app_path + GetItemPath(m_hitemDrop), cstra, SMRY_STATUS_NONE, SMRY_COLUMN_FROM);
-				sv->DeleteMail(m_ListItemDrag);
-				sv->WriteList();
+				sv->GetSelectedMail(ia);
+				sv->MoveMail(ia, app->m_app_path+GetItemPath(m_hitemDrop), SMRY_COLUMN_TO);
 				break;
 			default:
 				break;
