@@ -18,7 +18,7 @@
 #include "SettingAccountDlg.h"
 #include "lib.h"
 #include "MimeEncode.h"
-#include "_regex.h"
+//#include "_regex.h"
 #include "Gpg.h"
 #include "PassPhraseDlg.h"
 #include "direct.h"			// _mkdir
@@ -63,11 +63,7 @@ BEGIN_MESSAGE_MAP(CMainFrame, CFrameWnd)
 	ON_NOTIFY(TBN_DROPDOWN, AFX_IDW_TOOLBAR, OnToolbarDropDown)
 	ON_COMMAND(ID_REPLY_QUOTATION, OnReplyQuotation)
 	ON_COMMAND(ID_REPLY_NO_QUOTATION, OnReplyNoQuotation)
-	ON_COMMAND(ID_CHANGE_BK_COLOR, OnChangeBkColor)
-	ON_COMMAND(ID_CHANGE_TXT_COLOR, OnChangeTxtColor)
-	ON_COMMAND(ID_CHANGE_HD_TXT_COLOR, OnChangeHdTxtColor)
 	ON_WM_TIMER()
-	ON_COMMAND(ID_CHANGE_FONT, OnChangeFont)
 	ON_COMMAND(ID_SETTING_GENERAL, OnSettingGeneral)
 	ON_COMMAND(ID_SETTING_ACCOUNT, OnSettingAccount)
 	ON_COMMAND(ID_DISPLAY_HEADER, OnDisplayHeader)
@@ -76,6 +72,9 @@ BEGIN_MESSAGE_MAP(CMainFrame, CFrameWnd)
 	ON_COMMAND(ID_SETTING_NEW_ACCOUNT, OnSettingNewAccount)
 	ON_COMMAND(ID_TRANSFER_QUOTATION, OnTransferQuotation)
 	ON_COMMAND(ID_GPG_MAIN_KEY_MANAGEMENT, OnGpgKeyManagement)
+	ON_WM_CLOSE()
+	ON_WM_COPYDATA()
+	ON_WM_CHAR()
 	//}}AFX_MSG_MAP
 	ON_COMMAND(WM_PROGCREATE, OnProgCreate)
 END_MESSAGE_MAP()
@@ -122,28 +121,6 @@ int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
 	// toolbar̍쐬
 	if(!CreateToolbar())
 		return -1;
-	// hbv_Ej[
-	m_wndToolBar.GetToolBarCtrl().SetExtendedStyle(TBSTYLE_EX_DRAWDDARROWS);
-	// reply
-	DWORD style = m_wndToolBar.GetButtonStyle(m_wndToolBar.CommandToIndex(ID_REPLY));
-	style |= TBSTYLE_DROPDOWN;
-	m_wndToolBar.SetButtonStyle(m_wndToolBar.CommandToIndex(ID_REPLY), style);
-	// transfer
-	style = m_wndToolBar.GetButtonStyle(m_wndToolBar.CommandToIndex(ID_TRANSFER));
-	style |= TBSTYLE_DROPDOWN;
-	m_wndToolBar.SetButtonStyle(m_wndToolBar.CommandToIndex(ID_TRANSFER), style);
-	// gpg
-	style = m_wndToolBar.GetButtonStyle(m_wndToolBar.CommandToIndex(ID_GPG));
-	style |= TBSTYLE_DROPDOWN;
-	m_wndToolBar.SetButtonStyle(m_wndToolBar.CommandToIndex(ID_GPG), style);
-	// information
-	style = m_wndToolBar.GetButtonStyle(m_wndToolBar.CommandToIndex(ID_INFO));
-	style |= TBSTYLE_DROPDOWN;
-	m_wndToolBar.SetButtonStyle(m_wndToolBar.CommandToIndex(ID_INFO), style);
-	// setting
-	style = m_wndToolBar.GetButtonStyle(m_wndToolBar.CommandToIndex(ID_SETTING));
-	style |= TBSTYLE_DROPDOWN;
-	m_wndToolBar.SetButtonStyle(m_wndToolBar.CommandToIndex(ID_SETTING), style);
 
 	// statusbar̍쐬
 	if (!m_wndStatusBar.Create(this) ||
@@ -169,6 +146,10 @@ int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
 	rcWnd.bottom = app->GetProfileInt("wndPlace", "Bottom", 520);
 	MoveWindow(rcWnd);
 
+	// resurrect status of bar
+	this->m_wndToolBar.ShowWindow(app->GetProfileInt("ToolBar", "IsVisible", SW_SHOW));
+	this->m_wndStatusBar.ShowWindow(app->GetProfileInt("StatusBar", "IsVisible", SW_SHOW));
+
 	// MĂяoiontimersj
 	int minute = app->GetProfileInt("AutoFetch", "minute", 0);
 	if(minute >= 1){
@@ -180,6 +161,16 @@ int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
 
 BOOL CMainFrame::PreCreateWindow(CREATESTRUCT& cs)
 {
+    // EBhENXo^
+    // EBhE₷Ȃ邩HOOG
+	if (cs.lpszName){
+		WNDCLASS wc;
+		::GetClassInfo(AfxGetInstanceHandle(), cs.lpszClass, &wc);
+		// _T()ň͂ĂȂdebug[hŎsiHj
+		wc.lpszClassName = _T("_PochyClass"); // DȖOݒ
+		AfxRegisterClass(&wc);
+		cs.lpszClass = wc.lpszClassName;
+	}
 	if(!CFrameWnd::PreCreateWindow(cs))
 		return FALSE;
 	// TODO: ̈ʒu CREATESTRUCT cs CāAWindow NXX^CCĂB
@@ -273,10 +264,6 @@ void CMainFrame::OnFetchmail()
 	AfxBeginThread(FetchMail, this->m_pAcntV->GetCurrentAccountName());
 }
 
-void CMainFrame::OnSendmail()
-{
-}
-
 void CMainFrame::OnUpdateFetchmail(CCmdUI* pCmdUI)
 {
 	int index = m_pAcntV->GetAccountNum(m_pAcntV->GetCurrentAccountName());
@@ -428,6 +415,7 @@ void CMainFrame::OnRetrieve()
 
 void CMainFrame::OnDestroy()
 {
+	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	WINDOWPLACEMENT wndPlace;
 	CString num;
 
@@ -435,7 +423,6 @@ void CMainFrame::OnDestroy()
 	GetWindowPlacement(&wndPlace);
 
 	// EBhËʒuinit@Cɕۑ
-	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	app->WriteProfileInt("WndPlace", "Left", wndPlace.rcNormalPosition.left);
 	app->WriteProfileInt("WndPlace", "Top", wndPlace.rcNormalPosition.top);
 	app->WriteProfileInt("WndPlace", "Right", wndPlace.rcNormalPosition.right);
@@ -504,11 +491,6 @@ void CMainFrame::OnSetting()
 	this->OnSettingAccount();
 }
 
-/*void CMainFrame::OnMainTest()
-{
-
-}*/
-
 void CMainFrame::OnReply() 
 {
 	// ݒőIׂ悤ɂ
@@ -518,29 +500,47 @@ void CMainFrame::OnReply()
 void CMainFrame::OnDraft() 
 {
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
+	CString path = app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\account.ini";
 
-	// 
+	// initializing
 	app->m_me.Initialize();
 
-	// from̐ݒ
-	CString path = app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\account.ini";
-	CString address;
-	GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
-	address.ReleaseBuffer();
-	app->m_me.SetFrom(address);
+	// setting "from" field
+	CString from;
+	GetPrivateProfileString("mailbox", "address", "", from.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	from.ReleaseBuffer();
+	app->m_me.SetFrom(from);
 
-	// message-id̐ݒ
-	app->m_me.SetMessageID(g_gen_msgid(address));
+	// setting "cc" field
+	CString cc;
+	GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	cc.ReleaseBuffer();
+	app->m_me.SetCc(cc);
 
-	// ̎擾
+	// setting "bcc" field
+	CString bcc;
+	GetPrivateProfileString("def_address", "address", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	bcc.ReleaseBuffer();
+	app->m_me.SetBcc(bcc);
+
+	// setting "reply-to" field
+	CString reply_to;
+	GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	reply_to.ReleaseBuffer();
+	app->m_me.SetReplyTo(reply_to);
+
+	// setting "message-id" field
+	app->m_me.SetMessageID(g_gen_msgid(from));
+
+	// getitng signature
 	CString signature;
 	g_file2cstring(app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\signature", signature);
 
-	//{ݒ
+	// setting mail body
 	app->m_me.AddText("\r\n"+signature);
 
-	// window쐬
-	app->CreateDraftFrame();
+	// create window
+	app->CreateDraftFrame(this->m_pAcntV->GetCurrentAccountName());
 }
 
 void CMainFrame::OnAddress() 
@@ -560,7 +560,7 @@ void CMainFrame::OnInfo()
 }
 
 // OnChar͑啶A̋ʂ
-BOOL CMainFrame::Char(UINT nChar, CView* view)
+BOOL CMainFrame::Char(UINT nChar)
 {
 	int sc;
 	CRetrieve Retrieve;
@@ -678,8 +678,29 @@ BOOL CMainFrame::CreateToolbar()
 	m_wndToolBar.SetButtonInfo( 8, ID_INFO, TBSTYLE_BUTTON, 8);
 
 	//m_wndToolBar.SetButtonInfo(2, 0, TBSTYLE_SEP, 6);
- 
-    m_wndToolBar.GetToolBarCtrl().SetExtendedStyle(TBSTYLE_EX_DRAWDDARROWS);
+
+	// dropdown menu
+	m_wndToolBar.GetToolBarCtrl().SetExtendedStyle(TBSTYLE_EX_DRAWDDARROWS);
+	// reply
+	DWORD style = m_wndToolBar.GetButtonStyle(m_wndToolBar.CommandToIndex(ID_REPLY));
+	style |= TBSTYLE_DROPDOWN;
+	m_wndToolBar.SetButtonStyle(m_wndToolBar.CommandToIndex(ID_REPLY), style);
+	// transfer
+	style = m_wndToolBar.GetButtonStyle(m_wndToolBar.CommandToIndex(ID_TRANSFER));
+	style |= TBSTYLE_DROPDOWN;
+	m_wndToolBar.SetButtonStyle(m_wndToolBar.CommandToIndex(ID_TRANSFER), style);
+	// gpg
+	style = m_wndToolBar.GetButtonStyle(m_wndToolBar.CommandToIndex(ID_GPG));
+	style |= TBSTYLE_DROPDOWN;
+	m_wndToolBar.SetButtonStyle(m_wndToolBar.CommandToIndex(ID_GPG), style);
+	// information
+	style = m_wndToolBar.GetButtonStyle(m_wndToolBar.CommandToIndex(ID_INFO));
+	style |= TBSTYLE_DROPDOWN;
+	m_wndToolBar.SetButtonStyle(m_wndToolBar.CommandToIndex(ID_INFO), style);
+	// setting
+	style = m_wndToolBar.GetButtonStyle(m_wndToolBar.CommandToIndex(ID_SETTING));
+	style |= TBSTYLE_DROPDOWN;
+	m_wndToolBar.SetButtonStyle(m_wndToolBar.CommandToIndex(ID_SETTING), style);
 
 	return TRUE;
 }
@@ -756,6 +777,24 @@ void CMainFrame::OnReplyQuotation()
 		app->m_me.SetSubject("Re: "+m_pTextV->GetCurrentSubject());
 	}
 
+	// setting "cc" field
+	CString cc;
+	GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	cc.ReleaseBuffer();
+	app->m_me.SetCc(cc);
+
+	// setting "bcc" field
+	CString bcc;
+	GetPrivateProfileString("def_address", "address", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	bcc.ReleaseBuffer();
+	app->m_me.SetBcc(bcc);
+
+	// setting "reply-to" field
+	CString reply_to;
+	GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	reply_to.ReleaseBuffer();
+	app->m_me.SetReplyTo(reply_to);
+
 	// message-id̐ݒ
 	app->m_me.SetMessageID(g_gen_msgid(address));
 
@@ -775,7 +814,7 @@ void CMainFrame::OnReplyQuotation()
 	app->m_me.AddText(body+"\r\n"+signature);
 
 	// htgt[쐬
-	app->CreateDraftFrame();
+	app->CreateDraftFrame(this->m_pAcntV->GetCurrentAccountName());
 }
 
 void CMainFrame::OnReplyNoQuotation() 
@@ -791,10 +830,6 @@ void CMainFrame::OnReplyNoQuotation()
 	else
 		app->m_me.SetTo(m_pTextV->GetCurrentFrom());
 
-	// cc̐ݒ
-	if(!m_pTextV->GetCurrentCc().IsEmpty())
-		app->m_me.SetCc(m_pTextV->GetCurrentCc());
-
 	// From ̐ݒ
 	CString path = app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\account.ini";
 	CString address;
@@ -802,6 +837,30 @@ void CMainFrame::OnReplyNoQuotation()
 	address.ReleaseBuffer();
 	app->m_me.SetFrom(address);
 
+	// setting "cc" field
+	// cc̐ݒ
+	CString cc;
+	GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	cc.ReleaseBuffer();
+	if(!m_pTextV->GetCurrentCc().IsEmpty() && !cc.IsEmpty()){
+		app->m_me.SetCc(m_pTextV->GetCurrentCc()+", "+cc);
+	}else if(!m_pTextV->GetCurrentCc().IsEmpty() && cc.IsEmpty()){
+		app->m_me.SetCc(m_pTextV->GetCurrentCc());
+	}else if(m_pTextV->GetCurrentCc().IsEmpty() && !cc.IsEmpty()){
+		app->m_me.SetCc(cc);
+	}
+	// setting "bcc" field
+	CString bcc;
+	GetPrivateProfileString("def_address", "address", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	bcc.ReleaseBuffer();
+	app->m_me.SetBcc(bcc);
+
+	// setting "reply-to" field
+	CString reply_to;
+	GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	reply_to.ReleaseBuffer();
+	app->m_me.SetReplyTo(reply_to);
+
 	// message-id̐ݒ
 	app->m_me.SetMessageID(g_gen_msgid(address));
 
@@ -826,82 +885,7 @@ void CMainFrame::OnReplyNoQuotation()
 	data.m_encoding_type = "7bit";
 	app->m_me.AddMultipart(data);
 
-	app->CreateDraftFrame();
-}
-
-void CMainFrame::OnChangeBkColor() 
-{
-	CPochyApp* app = (CPochyApp*)AfxGetApp();
-	CColorDialog dlgColor(RGB(0,0,0), /*CC_PREVENTFULLOPEN*/NULL, NULL);
-	if(dlgColor.DoModal() == IDOK){
-		app->WriteProfileInt("MtPartViewColor","BkColorR",GetRValue(dlgColor.GetColor()));
-		app->WriteProfileInt("MtPartViewColor","BkColorG",GetGValue(dlgColor.GetColor()));
-		app->WriteProfileInt("MtPartViewColor","BkColorB",GetBValue(dlgColor.GetColor()));
-		app->WriteProfileInt("FolderViewColor","BkColorR",GetRValue(dlgColor.GetColor()));
-		app->WriteProfileInt("FolderViewColor","BkColorG",GetGValue(dlgColor.GetColor()));
-		app->WriteProfileInt("FolderViewColor","BkColorB",GetBValue(dlgColor.GetColor()));
-		app->WriteProfileInt("SummaryViewColor","BkColorR",GetRValue(dlgColor.GetColor()));
-		app->WriteProfileInt("SummaryViewColor","BkColorG",GetGValue(dlgColor.GetColor()));
-		app->WriteProfileInt("SummaryViewColor","BkColorB",GetBValue(dlgColor.GetColor()));
-		app->WriteProfileInt("TextViewColor","BkColorR",GetRValue(dlgColor.GetColor()));
-		app->WriteProfileInt("TextViewColor","BkColorG",GetGValue(dlgColor.GetColor()));
-		app->WriteProfileInt("TextViewColor","BkColorB",GetBValue(dlgColor.GetColor()));
-
-		m_pTreeV->GetTreeCtrl().SetBkColor(dlgColor.GetColor());
-		m_pListV->GetListCtrl().SetBkColor(dlgColor.GetColor());
-		m_pListV->GetListCtrl().SetTextBkColor(dlgColor.GetColor());
-		m_pListV->GetListCtrl().RedrawWindow();
-		m_pTextV->GetRichEditCtrl().SetBackgroundColor(FALSE, dlgColor.GetColor());
-		m_pMultiV->GetListCtrl().SetBkColor(dlgColor.GetColor());
-		m_pMultiV->GetListCtrl().SetTextBkColor(dlgColor.GetColor());
-		m_pMultiV->GetListCtrl().RedrawWindow();
-	}
-}
-
-void CMainFrame::OnChangeTxtColor() 
-{
-	CPochyApp* app = (CPochyApp*)AfxGetApp();
-	CColorDialog dlgColor(RGB(0,0,0), /*CC_PREVENTFULLOPEN*/NULL, NULL);
-	if(dlgColor.DoModal() == IDOK){
-		app->WriteProfileInt("MtPartViewColor","TxtColorR",GetRValue(dlgColor.GetColor()));
-		app->WriteProfileInt("MtPartViewColor","TxtColorG",GetGValue(dlgColor.GetColor()));
-		app->WriteProfileInt("MtPartViewColor","TxtColorB",GetBValue(dlgColor.GetColor()));
-		app->WriteProfileInt("FolderViewColor","TxtColorR",GetRValue(dlgColor.GetColor()));
-		app->WriteProfileInt("FolderViewColor","TxtColorG",GetGValue(dlgColor.GetColor()));
-		app->WriteProfileInt("FolderViewColor","TxtColorB",GetBValue(dlgColor.GetColor()));
-		app->WriteProfileInt("SummaryViewColor","TxtColorR",GetRValue(dlgColor.GetColor()));
-		app->WriteProfileInt("SummaryViewColor","TxtColorG",GetGValue(dlgColor.GetColor()));
-		app->WriteProfileInt("SummaryViewColor","TxtColorB",GetBValue(dlgColor.GetColor()));
-		app->WriteProfileInt("TextViewColor","TxtColorR",GetRValue(dlgColor.GetColor()));
-		app->WriteProfileInt("TextViewColor","TxtColorG",GetGValue(dlgColor.GetColor()));
-		app->WriteProfileInt("TextViewColor","TxtColorB",GetBValue(dlgColor.GetColor()));
-
-		m_pTreeV->GetTreeCtrl().SetTextColor(dlgColor.GetColor());
-		m_pListV->GetListCtrl().SetTextColor(dlgColor.GetColor());
-		m_pListV->GetListCtrl().SetTextColor(dlgColor.GetColor());
-		m_pListV->GetListCtrl().RedrawWindow();
-		CHARFORMAT2 cf;
-		cf.dwMask = CFM_COLOR;
-		cf.crTextColor = dlgColor.GetColor();
-		m_pTextV->GetRichEditCtrl().SetDefaultCharFormat(cf);
-		if(m_pTextV->GetWindowTextLength())
-			m_pTextV->ReDisplay();
-		m_pMultiV->GetListCtrl().SetTextColor(dlgColor.GetColor());
-		m_pMultiV->GetListCtrl().RedrawWindow();
-	}
-}
-
-void CMainFrame::OnChangeHdTxtColor() 
-{
-	CPochyApp* app = (CPochyApp*)AfxGetApp();
-	CColorDialog dlgColor(RGB(0,0,0), /*CC_PREVENTFULLOPEN*/NULL, NULL);
-	if(dlgColor.DoModal() == IDOK){
-		app->WriteProfileInt("TextViewHdColor","TxtColorR",GetRValue(dlgColor.GetColor()));
-		app->WriteProfileInt("TextViewHdColor","TxtColorG",GetGValue(dlgColor.GetColor()));
-		app->WriteProfileInt("TextViewHdColor","TxtColorB",GetBValue(dlgColor.GetColor()));
-		if(m_pTextV->GetWindowTextLength())
-			m_pTextV->ReDisplay();
-	}
+	app->CreateDraftFrame(this->m_pAcntV->GetCurrentAccountName());
 }
 
 void CMainFrame::OnGpg()
@@ -953,51 +937,6 @@ void CMainFrame::UpdateButton(BOOL b, CString account)
 	m_pAcntV->m_data[index].button_retrieve = b;
 }
 
-void CMainFrame::OnChangeFont()
-{
-
-/*
-typedef struct tagLOGFONT {
-   LONG lfHeight; 
-   LONG lfWidth; 
-   LONG lfEscapement; 
-   LONG lfOrientation; 
-   LONG lfWeight; 
-   BYTE lfItalic; 
-   BYTE lfUnderline; 
-   BYTE lfStrikeOut; 
-   BYTE lfCharSet; 
-   BYTE lfOutPrecision; 
-   BYTE lfClipPrecision; 
-   BYTE lfQuality; 
-   BYTE lfPitchAndFamily; 
-   TCHAR lfFaceName[LF_FACESIZE]; 
-} LOGFONT;
-*/
-
-	CPochyApp* app = (CPochyApp*)AfxGetApp();
-
-	CFont *current_font = m_pTextV->GetFontEx();
-	LOGFONT lf;
-	if(current_font != NULL){
-		current_font->GetLogFont(&lf);
-	}else{
-		::GetObject(GetStockObject(DEFAULT_GUI_FONT), sizeof(LOGFONT), &lf);
-	}
-
-	CFontDialog dlg(&lf, CF_SCREENFONTS|CF_INITTOLOGFONTSTRUCT);
-	if(dlg.DoModal() == IDOK){
-		m_pTextV->SetFontEx(lf);
-	}else{
-		return;
-	}
-
-	// save font setting in ini file.
-	app->WriteProfileBinary("TextViewFont", "LogFont", (LPBYTE)&lf, sizeof(LOGFONT));
-
-	m_pTextV->ReDisplay();
-}
-
 void CMainFrame::SetStatusBarProgress(int current, int upper)
 {
 	if(m_progress.m_hWnd == NULL)
@@ -1095,10 +1034,8 @@ void CMainFrame::OnSettingNewAccount()
 	this->m_pTreeV->ConstructTree(name);
 
 	// multipartview\ĂΉB
-	this->HideMultiPartView(TRUE);
-	CString empty = "";
-	this->m_pListV->SetItem(empty); // summaryviewɋ\
-	this->m_pTextV->Update(empty); // textviewɋ\
+	this->m_pListV->Clear();
+	this->m_pTextV->Clear();
 }
 
 void CMainFrame::OnTransferQuotation() 
@@ -1115,6 +1052,24 @@ void CMainFrame::OnTransferQuotation()
 	address.ReleaseBuffer();
 	app->m_me.SetFrom(address);
 
+	// setting "cc" field
+	CString cc;
+	GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	cc.ReleaseBuffer();
+	app->m_me.SetCc(cc);
+
+	// setting "bcc" field
+	CString bcc;
+	GetPrivateProfileString("def_address", "address", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	bcc.ReleaseBuffer();
+	app->m_me.SetBcc(bcc);
+
+	// setting "reply-to" field
+	CString reply_to;
+	GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	reply_to.ReleaseBuffer();
+	app->m_me.SetReplyTo(reply_to);
+
 	// message-id̐ݒ
 	app->m_me.SetMessageID(g_gen_msgid(address));
 
@@ -1145,7 +1100,7 @@ void CMainFrame::OnTransferQuotation()
 	// {ݒ
 	app->m_me.AddText(body+"\r\n"+signature);
 
-	app->CreateDraftFrame();	
+	app->CreateDraftFrame(this->m_pAcntV->GetCurrentAccountName());	
 }
 
 void CMainFrame::OnGpgKeyManagement() 
@@ -1153,3 +1108,85 @@ void CMainFrame::OnGpgKeyManagement()
 	CGpgDlg gd;
 	gd.DoModal();
 }
+
+void CMainFrame::OnClose() 
+{
+	CPochyApp *app = (CPochyApp *)AfxGetApp();
+
+	if(this->m_wndToolBar.IsWindowVisible()){
+		app->WriteProfileInt("ToolBar", "IsVisible", SW_SHOW);
+	}else{
+		app->WriteProfileInt("ToolBar", "IsVisible", SW_HIDE);
+	}
+
+	if(this->m_wndStatusBar.IsWindowVisible()){
+		app->WriteProfileInt("StatusBar", "IsVisible", SW_SHOW);
+	}else{
+		app->WriteProfileInt("StatusBar", "IsVisible", SW_HIDE);
+	}
+
+	CFrameWnd::OnClose();
+}
+
+BOOL CMainFrame::OnCopyData(CWnd* pWnd, COPYDATASTRUCT* pCopyDataStruct) 
+{
+	CString mailto;
+	if(pCopyDataStruct->dwData == WM_MAILTO){ 
+		mailto = (char *)pCopyDataStruct->lpData;
+		if(!mailto.IsEmpty() && mailto.Find("mailto:") == 0){
+			CPochyApp *app = (CPochyApp *)AfxGetApp();
+
+			// getting default account name
+			CString def_account = app->GetProfileString("DefaultMailBox", "BoxName");
+
+			app->m_me.Initialize();
+
+			// setting To
+			if(mailto.Find("?", 7) != -1){ // mailto:hoge@hoge.com?subject=PGP%20Key&Body=Please%20send%20keyƂ
+					// subject, body is not implemented.
+				app->m_me.SetTo(mailto.Mid(7, mailto.Find("?", 7)-7));
+			}else{
+				app->m_me.SetTo(mailto.Mid(7));
+			}
+
+			if(!def_account.IsEmpty()){
+				// setting From
+				CString path = app->m_app_path+"\\"+def_account+"\\account.ini";
+				CString address;
+				GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				address.ReleaseBuffer();
+				app->m_me.SetFrom(address);
+
+				// setting message-id
+				app->m_me.SetMessageID(g_gen_msgid(address));
+
+				// getting signature.
+				CString signature;
+				g_file2cstring(app->m_app_path+"\\"+def_account+"\\signature", signature);
+				// set main text.
+				app->m_me.AddText(signature);
+				// draftframe
+				app->CreateDraftFrame(def_account);
+			}else{
+				CString hostname;
+				char *tmp = hostname.GetBuffer(255);
+				DWORD size=255;
+				::GetUserName(tmp, &size);
+				hostname.ReleaseBuffer();
+				app->m_me.SetFrom("");
+				app->m_me.AddText("");
+				app->m_me.SetMessageID(g_gen_msgid(hostname));
+				// draftframe
+				app->CreateDraftFrame(this->m_pAcntV->GetFirstAccountName());
+			}
+		}
+	}
+	return CFrameWnd::OnCopyData(pWnd, pCopyDataStruct);
+}
+
+void CMainFrame::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags) 
+{
+	AfxMessageBox("this");
+	this->Char(nChar);
+	CFrameWnd::OnChar(nChar, nRepCnt, nFlags);
+}
