@@ -87,7 +87,6 @@ void CSummaryView::Dump(CDumpContext& dc) const
 
 void CSummaryView::OnInitialUpdate() 
 {
-
 	CListCtrl& lc = GetListCtrl();
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	int i;
@@ -131,6 +130,9 @@ void CSummaryView::OnInitialUpdate()
 		lvc.pszText = Column[i];
 		num.Format("%d", i);
 		lvc.cx = app->GetProfileInt("SummaryViewColumn", num.GetBuffer(0), 100);
+		if(lvc.cx > 1000){
+			lvc.cx = 100;
+		}
 		lc.InsertColumn(i, &lvc);
 	}
 
@@ -179,7 +181,7 @@ BOOL CSummaryView::PreCreateWindow(CREATESTRUCT& cs)
 	// SetItemCountExs邱ƂŁAOnGetdispinfoĂ΂
 	cs.style	|= LVS_OWNERDATA 
 				| LVS_REPORT 
-				| LVS_SINGLESEL 
+				/*| LVS_SINGLESEL*/ 
 				| LVS_SHOWSELALWAYS;
 	// LVS_SORTDESCENDING  LVS_SORTASCENDING
 
@@ -203,8 +205,8 @@ int CSummaryView::SetStack(CString path)
 		AfxMessageBox(message.GetBuffer(0));
 		return -1;
 #else
-		CString NullBuf;
-		NullBuf.Empty();
+//		CString NullBuf;
+//		NullBuf.Empty();
 		g_fcreate(path+"\\list");
 		if(!ReadFile.Open(path+"\\list", CFile::modeRead | CFile::typeText)){
 			message.Format("CSummaryView: cannot open %s\\list", path.GetBuffer(0));
@@ -263,8 +265,7 @@ void CSummaryView::SetItem(CString path)
 {
 	WriteList(); // 荇݂̓elistɕۑ
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
-//	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
-	CMainFrame *mf = (CMainFrame*)this->GetParentFrame(); // łapp->m_pMainWnd2͎gȂ
+	CMainFrame *mf = (CMainFrame*)this->GetParentFrame();
 	CListCtrl& lc = GetListCtrl();
 	lc.DeleteAllItems();
 	m_path = path; // ݕ\悤ƂĂlistt@ĈtH_̃pXm_pathɕۑ
@@ -272,7 +273,6 @@ void CSummaryView::SetItem(CString path)
 
 	CString current_account = mf->m_pAcntV->GetCurrentAccountName();
 
-	// ݂̃R̕ۑ
 	// Xgr[̃J̕init@C֕ۑ
 	CString num;
 	for(int i = 0; i < 5; i++){
@@ -283,9 +283,9 @@ void CSummaryView::SetItem(CString path)
 	// listview̃RKvɉĕύX
 	if(path == app->m_app_path+"\\"+current_account+"\\outbox"
 		|| path == app->m_app_path+"\\"+current_account+"\\draft")
-		UpdateColumn(SMRY_COLUMN_TO);
+		this->UpdateColumn(SMRY_COLUMN_TO);
 	else
-		UpdateColumn(SMRY_COLUMN_FROM);
+		this->UpdateColumn(SMRY_COLUMN_FROM);
 
 	m_stack_num = SetStack(path);
 
@@ -351,12 +351,12 @@ void CSummaryView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags)
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CFolderView *fv = (CFolderView *)mf->m_pTreeV;
-	CSummaryView *sv = (CSummaryView *)mf->m_pListV;
 	CStringArray cstra;
+	CUIntArray ia;
 
 	CString current_account = mf->m_pAcntV->GetCurrentAccountName();
 
-	if(mf->Char(nChar, this))
+	if(mf->Char(nChar))
 		return;
 
 	switch(nChar){
@@ -373,14 +373,17 @@ void CSummaryView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags)
 		}
 		break;
 	case 'x':
-		for(i=this->m_array_list.GetSize()-1;i>=0;i--)
-		if(this->m_array_list.GetAt(i).m_str6.Find("D") != -1){
-			if(fv->GetSelectedItemKind() != FV_TRASH){
-				cstra.RemoveAll();
-				g_file2cstra(m_path+"\\"+m_array_list.GetAt(i).m_str5, cstra);
-				sv->SaveMail(app->m_app_path+"\\"+current_account+"\\trash", cstra, SMRY_STATUS_NONE, SMRY_COLUMN_FROM);
+		for(i=0; i < this->m_array_list.GetSize(); i++){
+			if(this->m_array_list.GetAt(i).m_str6.Find("D") != -1){
+				ia.Add(i);
 			}
-			this->DeleteMail(m_stack_num-i-1);
+		}
+		if(fv->GetSelectedItemKind() != FV_TRASH){
+			this->MoveMail(ia, app->m_app_path+"\\"+current_account+"\\trash", SMRY_COLUMN_FROM);
+		}else{
+			CString null;
+			null.Empty();
+			this->MoveMail(ia, null, SMRY_COLUMN_FROM);
 		}
 		break;
 	case '<':
@@ -494,47 +497,33 @@ void CSummaryView::SelectPrev()
 	}
 }
 
-void CSummaryView::DeleteMail(int nItem)
+void CSummaryView::DeleteMail(CUIntArray &index_array)
 {
-	if(!this->m_array_list.GetSize() || nItem < 0 || nItem > this->m_stack_num -1)
+	if(index_array.GetSize() < 1){
 		return;
+	}
 
-	CPochyApp* app = (CPochyApp*)AfxGetApp();
+	CWaitCursor wait_cursor; // turn cursor into sandglass
+
+	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
+	CTextView *tv = (CTextView *)mf->m_pTextV;
+	CStringArray cstra;
 
+	int i = index_array.GetSize()-1;
+	while(i >= 0){
+		DeleteFile(m_path+"\\"+m_array_list.GetAt(m_stack_num-index_array.GetAt(i)-1).m_str5);
+		this->m_array_list.RemoveAt(m_stack_num-index_array.GetAt(i)-1);
+		this->m_stack_num--;
+		i--;
+	}
 	// something is changed.
+	this->GetListCtrl().DeleteAllItems();
+	this->m_index = -1;
+	this->GetListCtrl().SetItemCountEx(m_stack_num, LVSICF_NOSCROLL);
 	this->m_status_changed = TRUE;
-
-	// delete file
-	DeleteFile(m_path+"\\"+m_array_list.GetAt(m_stack_num-nItem-1).m_str5);
-
-	// delete from listctrl
-	if(m_index == nItem){
-		if(m_index < m_stack_num - 1){
-			SelectNext();
-			m_index--;
-		}else{
-			SelectPrev();
-		}
-	}else{
-		if(nItem < m_index)
-			m_index--;
-	}
-	CListCtrl& lc = GetListCtrl();
-	lc.DeleteItem(nItem);
-	if(!lc.GetItemCount()){
-		CString path;
-		path.Empty();
-		mf->m_pTextV->Update(path);
-		m_index = -1;
-	}
-	m_array_list.RemoveAt(m_stack_num-nItem-1);
-
-	m_stack_num--;
-	lc.SetItemCountEx(m_stack_num, LVSICF_NOSCROLL);
-
-	// write out to list file.
-	WriteList();
+	this->WriteList();
+	tv->Clear();
 }
 
 void CSummaryView::WriteList()
@@ -613,9 +602,12 @@ void CSummaryView::OnDblclk(NMHDR* pNMHDR, LRESULT* pResult)
 			app->m_me.AddMultipart(data);
 			i++;
 		}
-		if(fv->GetSelectedItemKind() == FV_DRAFT)
-			this->DeleteMail(index);
-		app->CreateDraftFrame();
+		if(fv->GetSelectedItemKind() == FV_DRAFT){
+			CUIntArray ia;
+			this->GetSelectedMail(ia);
+			this->DeleteMail(ia);
+		}
+		app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
 	}
 	*pResult = 0;
 }
@@ -627,27 +619,35 @@ void CSummaryView::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
 	CFolderView *fv = (CFolderView *)mf->m_pTreeV;
 	CStringArray cstra;
 	CString message;
+	CUIntArray ia;
 
 	CString current_account = mf->m_pAcntV->GetCurrentAccountName();
 
 	switch(nChar){
-		case 46: // delL[ꂽꍇAݑIĂ郁[trashɈڂ
+		case 46: // if press del key, delete mail
+			this->GetSelectedMail(ia);
 			if(this->m_index == -1){
 				return;
 			}
 			if(fv->GetSelectedItemKind() != FV_TRASH){
-				message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\ntrashɈڂĂ悢łH";
-				if(IDYES != AfxMessageBox(message, MB_YESNO))
-					return;
-				cstra.RemoveAll();
-				g_file2cstra(this->m_path+"\\"+this->m_array_list[this->m_stack_num-this->m_index-1].m_str5, cstra);
-				this->SaveMail(app->m_app_path+"\\"+current_account+"\\trash", cstra, SMRY_STATUS_NONE, SMRY_COLUMN_FROM);
+				if(ia.GetSize() == 1){
+					message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\ntrashɈڂĂ悢łH";
+				}else if(ia.GetSize() > 1){
+					message = "\r\n\r\ntrashɈڂĂ悢łH";
+				}
+				if(IDYES == AfxMessageBox(message, MB_YESNO)){
+					this->MoveMail(ia, app->m_app_path+"\\"+current_account+"\\trash", SMRY_COLUMN_FROM);
+				}
 			}else{
-				message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\n폜Ă悢łH";
-				if(IDYES != AfxMessageBox(message, MB_YESNO))
-				return;
+				if(ia.GetSize() == 1){
+					message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\n폜Ă悢łH";
+				}else if(ia.GetSize() > 1){
+					message = "\r\n\r\n폜Ă悢łH";
+				}
+				if(IDYES == AfxMessageBox(message, MB_YESNO)){
+					this->DeleteMail(ia);
+				}
 			}
-			this->DeleteMail(m_index);
 			break;
 		default:
 			break;
@@ -663,6 +663,7 @@ void CSummaryView::OnSetFocus(CWnd* pOldWnd)
 void CSummaryView::OnBegindrag(NMHDR* pNMHDR, LRESULT* pResult) 
 {
 	NM_LISTVIEW* pNMListView = (NM_LISTVIEW*)pNMHDR;
+	CUIntArray ia;
 
 	CListCtrl &lc = GetListCtrl();
 	CPochyApp* app = (CPochyApp*)AfxGetApp();
@@ -673,11 +674,15 @@ void CSummaryView::OnBegindrag(NMHDR* pNMHDR, LRESULT* pResult)
 
 	POINT pt;
 	pt.x = pt.y = 8;
-	fv->m_pDragImage = lc.CreateDragImage(fv->m_ListItemDrag, &pt);
-	fv->m_pDragImage->BeginDrag(0, CPoint (8, 8));
+	this->GetSelectedMail(ia);
+	if(ia.GetSize() > 1){
+		fv->m_drag_image.BeginDrag(1, CPoint(8, 8));
+	}else{
+		fv->m_drag_image.BeginDrag(0, CPoint(8, 8));
+	}
 	pt = pNMListView->ptAction;
 	ClientToScreen(&pt);
-	fv->m_pDragImage->DragEnter(NULL, pt);
+	fv->m_drag_image.DragEnter(NULL, pt);
 
 	fv->m_bLDragging = TRUE;
 	fv->m_hitemDrop = NULL;
@@ -686,8 +691,12 @@ void CSummaryView::OnBegindrag(NMHDR* pNMHDR, LRESULT* pResult)
 	*pResult = 0;
 }
 
-BOOL CSummaryView::SaveMail(CString path, CString mail, int mode_status, int mode_box)
+BOOL CSummaryView::SaveMail(CString path, CString mail, int mail_status, int what_kind_box)
 {
+	if(path.IsEmpty()){
+		return FALSE;
+	}
+
 	CString header;
 	CString list;
 	CString subject;
@@ -766,11 +775,11 @@ BOOL CSummaryView::SaveMail(CString path, CString mail, int mode_status, int mod
 	}
 
 	// stat̐ݒ
-	if(hi.GetBoundary().IsEmpty() && mode_status == SMRY_STATUS_NEW)
+	if(hi.GetBoundary().IsEmpty() && mail_status == SMRY_STATUS_NEW)
 		stat = "N ";
-	else if(!hi.GetBoundary().IsEmpty() && mode_status == SMRY_STATUS_NONE)
+	else if(!hi.GetBoundary().IsEmpty() && mail_status == SMRY_STATUS_NONE)
 		stat = " M";
-	else if(hi.GetBoundary().IsEmpty() && mode_status == SMRY_STATUS_NONE)
+	else if(hi.GetBoundary().IsEmpty() && mail_status == SMRY_STATUS_NONE)
 		stat = "  ";
 	else
 		stat = "NM";
@@ -781,7 +790,7 @@ BOOL CSummaryView::SaveMail(CString path, CString mail, int mode_status, int mod
 	list += subject;
 	list += "\x02";
 	// ۑɂăT}[ɕ\񂪈Ⴄ
-	if(mode_box == SMRY_COLUMN_TO)
+	if(what_kind_box == SMRY_COLUMN_TO)
 		list += to;
 	else
 		list += from;
@@ -817,7 +826,7 @@ BOOL CSummaryView::SaveMail(CString path, CString mail, int mode_status, int mod
 	data.m_str1 = size;
 	data.m_str2 = subject;
 	// ۑɂăT}[ɕ\񂪈Ⴄ
-	if(mode_box == SMRY_COLUMN_TO)
+	if(what_kind_box == SMRY_COLUMN_TO)
 		data.m_str3 = to;
 	else
 		data.m_str3 = from;
@@ -844,8 +853,12 @@ BOOL CSummaryView::SaveMail(CString path, CString mail, int mode_status, int mod
 	return TRUE;
 }
 
-BOOL CSummaryView::SaveMail(CString path, CStringArray &mail, int mode_status, int mode_box)
+BOOL CSummaryView::SaveMail(CString path, CStringArray &mail, int mail_status, int what_kind_box)
 {
+	if(path.IsEmpty()){
+		return FALSE;
+	}
+
 	CString header;
 	CString list;
 	CString subject;
@@ -911,11 +924,11 @@ BOOL CSummaryView::SaveMail(CString path, CStringArray &mail, int mode_status, i
 	}
 
 	// set current status to stat.
-	if(hi.GetBoundary().IsEmpty() && mode_status == SMRY_STATUS_NEW)
+	if(hi.GetBoundary().IsEmpty() && mail_status == SMRY_STATUS_NEW)
 		stat = "N ";
-	else if(!hi.GetBoundary().IsEmpty() && mode_status == SMRY_STATUS_NONE)
+	else if(!hi.GetBoundary().IsEmpty() && mail_status == SMRY_STATUS_NONE)
 		stat = " M";
-	else if(hi.GetBoundary().IsEmpty() && mode_status == SMRY_STATUS_NONE)
+	else if(hi.GetBoundary().IsEmpty() && mail_status == SMRY_STATUS_NONE)
 		stat = "  ";
 	else
 		stat = "NM";
@@ -927,7 +940,7 @@ BOOL CSummaryView::SaveMail(CString path, CStringArray &mail, int mode_status, i
 	list += "\x02";
 	// content of summaryview is changable up to which folder is seleceted.
 	// especialy, outbox is selected, summaryview display [To] address instead of [From] address.
-	if(mode_box == SMRY_COLUMN_TO)
+	if(what_kind_box == SMRY_COLUMN_TO)
 		list += to;
 	else
 		list += from;
@@ -965,7 +978,7 @@ BOOL CSummaryView::SaveMail(CString path, CStringArray &mail, int mode_status, i
 	// content of summaryview is changing up to which folder is selected in folderview.
 	// if outbox is selected, summaryview display [To] address instead of [From].
 	// if other box but outbox is selected, viceversa.
-	if(mode_box == SMRY_COLUMN_TO)
+	if(what_kind_box == SMRY_COLUMN_TO)
 		data.m_str3 = to;
 	else
 		data.m_str3 = from;
@@ -1501,9 +1514,21 @@ void CSummaryView::OnRclick(NMHDR* pNMHDR, LRESULT* pResult)
 
 	CMenu menu;
 	menu.LoadMenu(IDR_SUMMARYVIEW_POPUP);
+
+	CUIntArray ia;
+	this->GetSelectedMail(ia);
+	if(ia.GetSize() > 1){
+		// 폜𖳌ɂ
+		menu.EnableMenuItem(ID_SUMMARYVIEW_HEADER_INFO, MF_GRAYED);
+		menu.EnableMenuItem(ID_SUMMARYVIEW_RAWMAIL_INFO, MF_GRAYED);
+	}else{
+		// Lɂ
+		menu.EnableMenuItem(ID_SUMMARYVIEW_HEADER_INFO, MF_ENABLED);
+		menu.EnableMenuItem(ID_SUMMARYVIEW_RAWMAIL_INFO, MF_ENABLED);
+	}
+
 	CMenu *popup = menu.GetSubMenu(0);
 	popup->TrackPopupMenu(TPM_LEFTALIGN | TPM_RIGHTBUTTON |TPM_LEFTBUTTON, (int)pt2.x, (int)pt2.y, this);
-
 	*pResult = 0;
 }
 
@@ -1516,25 +1541,32 @@ void CSummaryView::OnPopupDel()
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CFolderView *fv = (CFolderView *)mf->m_pTreeV;
 	CStringArray cstra;
+	CUIntArray ia;
 	CString message;
 
 	CString current_account = mf->m_pAcntV->GetCurrentAccountName();
+	this->GetSelectedMail(ia);
 	if(fv->GetSelectedItemKind() != FV_TRASH){
-		message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\ntrashɈڂĂ悢łH";
-		if(IDYES != AfxMessageBox(message, MB_YESNO))
+		if(ia.GetSize() == 1){
+			message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\ntrashɈڂĂ悢łH";
+		}else if(ia.GetSize() > 1){
+			message = "\r\n\r\ntrashɈڂĂ悢łH";
+		}
+		if(IDYES != AfxMessageBox(message, MB_YESNO)){
 			return;
-		cstra.RemoveAll();
-		g_file2cstra(this->m_path+"\\"+this->m_array_list[this->m_stack_num-this->m_index-1].m_str5,
-			cstra);
-		this->SaveMail(app->m_app_path+"\\"+current_account+"\\trash",
-			cstra,
-			SMRY_STATUS_NONE, SMRY_COLUMN_FROM);
+		}
+		this->MoveMail(ia, app->m_app_path+"\\"+current_account+"\\trash", SMRY_COLUMN_FROM);
 	}else{
-		message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\n폜Ă悢łH";
-		if(IDYES != AfxMessageBox(message, MB_YESNO))
+		if(ia.GetSize() == 1){
+			message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\n폜Ă悢łH";
+		}else if(ia.GetSize() > 1){
+			message = "\r\n\r\n폜Ă悢łH";
+		}
+		if(IDYES != AfxMessageBox(message, MB_YESNO)){
 			return;
+		}		
+		this->DeleteMail(ia);
 	}
-	this->DeleteMail(m_index);
 }
 
 void CSummaryView::OnPopupHeaderInfo() 
@@ -1609,3 +1641,66 @@ void CSummaryView::ClearAllMail(CString path)
 		}
 	}
 }
+
+void CSummaryView::MoveMail(CUIntArray &index_array, CString to, int what_kind_box)
+{
+	if(to.IsEmpty() || index_array.GetSize() < 1){
+		return;
+	}
+	
+	CWaitCursor wait_cursor; // turn cursor into sandglass
+
+	CPochyApp *app = (CPochyApp *)AfxGetApp();
+	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
+	CTextView *tv = (CTextView *)mf->m_pTextV;
+	CStringArray cstra;
+
+	int i=0;
+	while(i < index_array.GetSize()){
+		cstra.RemoveAll();
+		g_file2cstra(this->m_path+"\\"+this->m_array_list.GetAt(this->m_stack_num-index_array.GetAt(i)-1).m_str5, cstra);
+		this->SaveMail(to, cstra, SMRY_STATUS_NONE, what_kind_box);
+		i++;
+	}
+	this->DeleteMail(index_array);
+}
+
+void CSummaryView::Clear()
+{
+	// first of all, save current summary list into list file
+	WriteList();
+
+	CPochyApp *app = (CPochyApp *)AfxGetApp();
+	CMainFrame *mf = (CMainFrame*)this->GetParentFrame();
+	CListCtrl& lc = GetListCtrl();
+
+	// delete all item;	
+	lc.DeleteAllItems();
+	this->m_array_list.RemoveAll();
+	this->m_stack_num = 0;
+	this->m_path.Empty();
+	this->m_unread = 0;
+	this->m_index = -1;
+
+	// save width of listview column into ini file
+	CString num;
+	for(int i = 0; i < 5; i++){
+		num.Format("%d", i);
+		app->WriteProfileInt("SummaryViewColumn", num.GetBuffer(0), lc.GetColumnWidth(i));
+	}
+
+	// change column text for default
+	this->UpdateColumn(SMRY_COLUMN_FROM);
+
+	// renew infomation of mail in statusbar
+	mf->SetStatusBarText(2, " 0  [ 0");
+}
+
+void CSummaryView::GetSelectedMail(CUIntArray &index_array)
+{
+	POSITION pos = this->GetListCtrl().GetFirstSelectedItemPosition();
+	index_array.RemoveAll();
+	while(pos){
+		index_array.Add(this->GetListCtrl().GetNextSelectedItem(pos));
+	}
+}
