@@ -18,7 +18,7 @@
 #include <Shlwapi.h> // StrStrI vWFNg̐ݒ̃N"Shlwapi.lib"ǉ
 #include "quoted-printable.h"
 #include "base64.h"
-#include "_regex.h"
+//#include "_regex.h"
 #include "lib.h"
 #include "direct.h"			// _mkdir
 #include "Gpg.h"
@@ -199,7 +199,7 @@ void CTextView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags)
 	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 
-	if(mf->Char(nChar, this))
+	if(mf->Char(nChar))
 		return;
 
 	switch(nChar){
@@ -325,10 +325,10 @@ void CTextView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
 			// set main text.
 			app->m_me.AddText(signature);
 			// draftframe
-			app->CreateDraftFrame();
-		}
-		else
+			app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
+		}else{
 			ShellExecute(this->GetSafeHwnd(), _T( "open" ), link, NULL, NULL, SW_NORMAL);
+		}
 	}
 }
 
@@ -441,13 +441,10 @@ void CTextView::Update(CString path)
 
 	// after getting 0st element of MULTIPARTSTRUCT in mimedecode class, and display.
 	if(path.IsEmpty()){ // if empty, not display. 
-		SetWindowText("");
-		mf->HideMultiPartView(TRUE);
-		m_current_part = -1;
+		this->Clear();
 	}else{
 		if(!m_md.DoIt(path)){ // analyze mime structure of mail.
-			SetWindowText("");
-			mf->HideMultiPartView(TRUE);
+			this->Clear();
 			return;
 		}
 		DisplayPart(0); // anyway, 0st element of MULTIPARTSTRUCT is on display.
@@ -516,14 +513,11 @@ void CTextView::Update2(CString mail)
 
 	// ȉmimedecodeMULTIPARTSTRUCT0Ԗڂ̗vf擾ĕ\
 	if(mail.IsEmpty()){ // ̏ꍇ͉\Ȃ
-		SetWindowText("");
-		mf->HideMultiPartView(TRUE);
-		m_current_part = -1;
+		this->Clear();
 	}else{
 		if(!m_md.DoIt2(mail)){ // [mime\𕪐͂
 			// [Ăꍇ͂̂܂ܕ\B
-			SetWindowText("");
-			mf->HideMultiPartView(TRUE);
+			this->Clear();
 			return;
 		}
 		DisplayPart(0); // 肠AMULTIPARTSTRUCT0Ԗڂ̗vf\
@@ -771,3 +765,21 @@ CFont *CTextView::GetFontEx()
 {
 	return &m_font;
 }
+
+void CTextView::Clear()
+{
+	CPochyApp* app = (CPochyApp*)AfxGetApp();
+	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
+
+	this->SetWindowText("");
+	this->m_current_part = 0;
+	this->m_body.Empty();
+	this->m_current_part = -1;
+	this->m_display_header.Empty();
+	this->m_header.Empty();
+	this->m_mail.Empty();
+	this->m_multipart_header.Empty();
+	this->m_path.Empty();
+
+	mf->HideMultiPartView(TRUE);
+}
