@@ -35,8 +35,11 @@ BOOL g_cstr_compare(LPCTSTR c, LPCTSTR d)
 	CString regex;
 	regex.Format("^%s$", c);
 	regcomp(&reg, regex.GetBuffer(0), REG_EXTENDED | REG_NEWLINE | REG_ICASE |REG_NOSUB );
-	if(0 == regexec(&reg, d, 2, pmatch, 0))
+	if(0 == regexec(&reg, d, 2, pmatch, 0)){
+		regfree(&reg);
 		return TRUE;
+	}
+	regfree(&reg);
 	return FALSE;
 }
 
